@@ -12,14 +12,14 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@csit.fsu.edu
+ beerli@scs.fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: fst.h 175 2005-12-02 14:51:23Z beerli $
+$Id: fst.h 633 2007-03-06 04:14:07Z beerli $
 -------------------------------------------------------*/
-extern void fst_type (char type);
+extern void fst_type (int type);
 extern void calc_fst (world_fmt * world, data_fmt * data);
 
 #endif /* FST_INCLUDE */
