@@ -8,12 +8,12 @@
  Laguerre integration  R O U T I N E S 
  
  Peter Beerli 2000, Seattle
- beerli@csit.fsu.edu
+ beerli@scs.fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: laguerre.h 175 2005-12-02 14:51:23Z beerli $
+$Id: laguerre.h 514 2006-11-09 20:14:08Z beerli $
 -------------------------------------------------------*/
 
 extern void integrate_laguerre (long categs, MYREAL *rate,
