@@ -13,3 +13,9 @@ void set_haru_handler() {
   _set_new_handler(throw_new_handler);
 }
 #endif
+
+int dummy_function(int do_nothing)
+{
+  print("Some computer fail to compile MIGRATE with empty files\n");
+  return 0;
+}
