@@ -45,7 +45,7 @@ extern void pdf_print_spectra(data_fmt *data, MYREAL ***freq, long * maxalleles)
 extern void pdf_print_bayestable(world_fmt *world);
 // print histogram at location lx ly with widht and height
 extern void pdf_histogram(MYREAL *binvals, char *set50, char *set95, long bins, float bindelta, float binmin, float binmax, float lx, float ly, float width, float height, boolean nofreq);
-extern void pdf_histogram_plus(MYREAL *binvals, MYREAL *std, char *set50, char *set95, long bins, float bindelta, float binmin, float binmax, float lx, float ly, float width, float height, MYREAL scaler, boolean nofreq, world_fmt * world, float *confidence);
+extern void pdf_histogram_plus(MYREAL *binvals, MYREAL *std, char *set50, char *set95, long bins, float bindelta, float binmin, float binmax, float lx, float ly, float width, float height, MYREAL scaler, boolean nofreq, world_fmt * world, float *confidence, long topop);
 // print histogram for each locus and overall loci
 extern float pdf_loci_histogram(world_fmt *world);
 // print acceptance ratios
