@@ -17,16 +17,16 @@
  and finally helps to destroy itself.
                                                                                                                
  Peter Beerli, started 1996
- beerli@csit.fsu.edu
+ beerli@scs.fsu.edu
  
-Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
-Copyright 2003 Peter Beerli, Tallahassee FL
+Copyright 1996-2003 Peter Beerli and Joseph Felsenstein, Seattle WA
+Copyright 2003-2006 Peter Beerli, Tallahassee FL
 
 This software is distributed free of charge for non-commercial use
 and is copyrighted. Of course, we do not guarantee that the software
 works and are not responsible for any damage you may cause or have.
 
-$Id: world.h 209 2005-12-26 23:13:22Z beerli $
+$Id: world.h 608 2007-02-17 23:32:53Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -85,4 +85,5 @@ extern void print_mighist (world_fmt * world);
 extern void print_gelmanr (MYREAL average, MYREAL biggest);
 extern void prognose_time (char *nowstr, world_fmt * world,
                            long options_increment, long steps, char *spacer, boolean tobuffer);
+extern boolean is_same(long i, long j);
 #endif /*WORLD_INCLUDE */
